@@ -157,7 +157,7 @@ instead of undefined characters.")
                 (setq code (cons 8 code)
                       cursor-position nil)
               (decf cursor-position)))
-          (flet ((display-dot (dot)
+          (cl-flet ((display-dot (dot)
                    (end-of-line)
                    (insert (if (member dot code) "o" " ") suffix)
                    (forward-line)))
