@@ -1,7 +1,7 @@
 ;;; brltty.el --- Interface to BRLTTY
 
 ;; Copyright (C) 2004, 2005, 2006, 2007, 2008 Brailcom, o.p.s.
-;; Copyright (C) 2012, 2013 Milan Zamazal <pdm@zamazal.org>
+;; Copyright (C) 2012, 2013, 2020 Milan Zamazal <pdm@zamazal.org>
 
 ;; Author: Milan Zamazal <pdm@brailcom.org>
 
@@ -265,7 +265,7 @@ available, from the  environment variable CONTROLVT."
 (defun brltty--read-packet (connection)
   (condition-case err
       (let ((process (brltty--connection-process connection)))
-        (flet ((read-enough-output (size)
+        (cl-flet ((read-enough-output (size)
                  (while (< (length (brltty--connection-output connection)) size)
                    (brltty--accept-process-output process)))
                (read-integer ()
@@ -364,16 +364,17 @@ available, from the  environment variable CONTROLVT."
     (when process
       (with-speechd-coding-protection
         (condition-case err
-            (flet ((send-integer (n)
+            (cl-flet ((send-integer (n)
                      (process-send-string
                       process
-                      (string-make-unibyte
+                      (encode-coding-string
                        (apply #'format "%c%c%c%c"
                               (funcall #'reverse
                                        (loop for i from 1 to 4
                                              for x = n then (/ x 256)
                                              for rem = (% x 256)
-                                             collect rem)))))))
+                                             collect rem)))
+                       brltty-coding))))
               (send-integer length)
               (send-integer (cdr (assoc packet-id brltty--packet-types)))
               (dolist (data data-list)
@@ -384,17 +385,18 @@ available, from the  environment variable CONTROLVT."
                   (dotimes (i (length data))
                     (process-send-string
                      process
-                     (string-make-unibyte (format "%c" (aref data i))))))
+                     (encode-coding-string (format "%c" (aref data i)) brltty-coding))))
                  ((consp data)
                   (destructuring-bind (n1 n2 n3) (cdr data)
                     (ecase (car data)
                       (integer64
                        (process-send-string
                         process
-                        (string-make-unibyte (format "%c%c%c%c%c%c%c%c"
+                        (encode-coding-string (format "%c%c%c%c%c%c%c%c"
                                                      (/ n1 256) (% n1 256)
                                                      (/ n2 (* 256 256)) (% (/ n2 256) 256) (% n2 256)
-                                                     (/ n3 (* 256 256)) (% (/ n3 256) 256) (% n3 256))))))))
+                                                     (/ n3 (* 256 256)) (% (/ n3 256) 256) (% n3 256))
+                                              brltty-coding))))))
                  (t
                   (process-send-string process data))))
               (when answer
@@ -444,9 +446,7 @@ respectively."
               (let ((auth-methods (brltty--send-packet connection 'auth 'version version)))
                 (cond
                  ((memq 'none auth-methods)
-                  (brltty--send-packet
-                   connection 'ack 'auth
-                   (car (rassoc 'none brltty--authentication-codes))))
+                  nil)
                  ((memq 'key auth-methods)
                   (brltty--send-packet
                    connection 'ack 'auth
