@@ -1,6 +1,6 @@
 ;;; speechd-compile.el --- Maintenance utilities
 
-;; Copyright (C) 2004 Milan Zamazal
+;; Copyright (C) 2004, 2013 Milan Zamazal <pdm@zamazal.org>
 
 ;; Author: Milan Zamazal <pdm@zamazal.org>
 
@@ -27,7 +27,8 @@
 (defun speechd-compile ()
   (let ((load-path (cons default-directory load-path)))
     (dolist (file (directory-files "." nil "\\.el$"))
-      (unless (string= file "speechd-compile.el")
+      (unless (member file '("speechd-compile.el"
+                             "speechd-el-pkg.el"))
         (load file)
         (byte-compile-file file)))))
 
