@@ -1,7 +1,7 @@
 ;;; speechd-speak.el --- simple speechd-el based Emacs client
 
 ;; Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2010 Brailcom, o.p.s.
-;; Copyright (C) 2012, 2013 Milan Zamazal <pdm@zamazal.org>
+;; Copyright (C) 2012, 2013, 2016, 2019 Milan Zamazal <pdm@zamazal.org>
 
 ;; Author: Milan Zamazal <pdm@brailcom.org>
 
@@ -164,7 +164,7 @@ and the keys are read after the command is performed."
 (defcustom speechd-speak-ignore-command-keys
   '(forward-char backward-char right-char left-char next-line previous-line
     delete-char comint-delchar-or-maybe-eof delete-backward-char
-    backward-delete-char-untabify
+    backward-delete-char-untabify delete-forward-char
     c-electric-backspace c-electric-delete-forward)
   "List of commands for which their keys are never read."
   :type '(repeat function)
@@ -293,7 +293,7 @@ created."
   '(empty whitespace beginning-of-line end-of-line start finish minibuffer
     message)
   "List of symbolic names of events to signal with a standard icon.
-The following actions are supported: `empty', `beginning-of-line',
+The following actions are supported: `empty', `whitespace', `beginning-of-line',
 `end-of-line', `start', `finish', `minibuffer', `message'."
   :type '(set (const empty)
               (const whitespace)
@@ -803,8 +803,10 @@ FUNCTION is a function name.
 POSITION may be one of the symbols `before' (the feedback is run before the
 function is invoked) or `after' (the feedback is run after the function is
 invoked.
-FEEDBACK is a string to be given as the argument of the `speechd-speak-report'
-function or a sexp to be evaluated."
+FEEDBACK is a string or a sexp.  If it is a string, it is simply passed as an
+argument to `speechd-speak-report'.  If it is a sexp then it is evaluated as it
+is when the feedback is run; the expression must itself deliver something to
+output (by using speechd-speak-report or other function)."
   `(speechd-speak--defadvice ,(list function) ,position
      (speechd-speak--report ,feedback :priority 'message)))
 
@@ -878,17 +880,6 @@ Language must be an RFC 1766 language code, as a string."
 
 ;;; Basic speaking
 
-
-;; These two simply don't work in Emacs 21.3 when invoked via key binding.
-;; They're called directly in Emacs 21, to speed them up; no advice is invoked
-;; in such a case.
-
-;; (speechd-speak--command-feedback (self-insert-command) after
-;;   (speechd-speak--char (preceding-char)))
-
-;; (speechd-speak--command-feedback (forward-char backward-char) after
-;;   (speechd-speak-read-char))
-
 (speechd-speak--command-feedback (next-line previous-line) after
   (speechd-speak-read-line))
 
@@ -917,10 +908,7 @@ Language must be an RFC 1766 language code, as a string."
 
 (defun speechd-speak--store-deleted-chars (text)
   (speechd-speak--with-command-start-info
-    (setf (speechd-speak--cinfo deleted-chars)
-          (if (speechd-speak--cinfo deleted-chars)
-              t
-            text))))
+    (setf (speechd-speak--cinfo deleted-chars) text)))
 
 (speechd-speak--defadvice (delete-backward-char backward-delete-char) around
   (if (speechd-speak--command-start-info)
@@ -937,7 +925,7 @@ Language must be an RFC 1766 language code, as a string."
                                              (format "%c" (preceding-char))))))
     ad-do-it))
   
-(speechd-speak--defadvice (delete-char) around
+(speechd-speak--defadvice (delete-forward-char delete-char) around
   (let ((speechd-speak--deleted-chars
          (when speechd-speak-deleted-char
            (speechd-speak--buffer-substring
@@ -1893,7 +1881,7 @@ When the mode is enabled, all spoken text is spelled."
                         (cadr mode-spec)
                       mode)))
   :on-change #'(lambda (old new)
-                 (flet ((set-difference (x y)
+                 (cl-flet ((set-difference (x y)
                           (loop for i in x
                                 unless (memq i y)
                                 collect i)))
@@ -2106,7 +2094,7 @@ the value of the `speechd-speak-prefix' variable:
 ;; is called.  So we have to be a bit more aggressive about it sometimes.  The
 ;; same applies to global-speechd-speak-mode.
 (defun speechd-speak--enforce-speak-mode ()
-  (flet ((enforce-mode (global-mode local-mode-var)
+  (cl-flet ((enforce-mode (global-mode local-mode-var)
            (when (and global-mode
                       (not (symbol-value local-mode-var))
                       (not (local-variable-p local-mode-var)))
